
/*
 * Same as my other solution except uses Ford-Fulkerson
 * for the flow.
 */


import java.util.*;
import java.io.*;

public class AbstractArt_ff_font
{
   public static void main(String[] args) throws Exception
   {
      PrintWriter out = new PrintWriter(System.out);
      new AbstractArt_ff_font(new FastScanner(System.in), out);
      out.close();
   }

   int N, M;
   char[][] grid, backup;
   int[] dr = {-1,0,1,0};
   int[] dc = {0,-1,0,1};
   int minVertexCover;
   int getNode(int i, int j)
   {
      return i * M + j;
   }

   ArrayList<Edge>[] adj;
   void addEdge(int i, int j, boolean isMatched)
   {
      adj[i].add(new Edge(i,j,isMatched));
      adj[j].add(new Edge(j,i,isMatched));
   }

   // Run flow to find the vertex cover.
   int matchOppositeColors()
   {
      FordFulkerson flowSolver = new FordFulkerson(N*M);

      for (int i=0; i<N; i++)
      {
         for (int j=0; j<M; j++)
         {
            if (grid[i][j] == '#')
               continue;
            
            if ((i+j) % 2 == 0)
            {
               flowSolver.addEdge(flowSolver.source, getNode(i,j), 1);
               for (int u=0; u<4; u++)
               {
                  int ni = i+dr[u]; 
                  int nj = j+dc[u]; 

                  // Check to see if the two colors are opposite.
                  if (0 <= ni && ni < N && 0 <= nj && nj < M &&
                     grid[ni][nj] != '#' && grid[i][j] != grid[ni][nj])
                  {
                     flowSolver.addEdge(getNode(i,j), getNode(ni,nj), 1);
                  }
               }
            }
            else
            {
               flowSolver.addEdge(getNode(i,j), flowSolver.sink, 1); 
            }
         }
      }

      adj = new ArrayList[N*M];
      for (int i=0; i<adj.length; i++)
         adj[i] = new ArrayList<>();

      int minVertexCover = flowSolver.run();

      // Save the matching
      for (int i=0; i<N; i++)
      {
         for (int j=0; j<M; j++)
         {
            if (grid[i][j] == '#')
               continue;

            if ((i+j) % 2 == 0)
            {
               int x = getNode(i,j);
               for (FordFulkerson.Edge e : flowSolver.adj[x])
               {
                  if (e.j != flowSolver.source)
                  {
                     addEdge(e.i, e.j, e.cap == 0);
                  }
               }
            }
         }
      } 

      return minVertexCover;
   }

   boolean[] getIndependentSet(int bit)
   {
      boolean[] Z = new boolean[N*M];
      ArrayDeque<Integer> q = new ArrayDeque<>();

      boolean[] side = new boolean[N*M];
      for (int i=0; i<N; i++)
      {
         for (int j=0; j<M; j++)
         {
            if (grid[i][j] == '#')
               continue;

            int x = getNode(i,j);
            side[x] = (i+j) % 2 == bit;
            if (side[x])
            {
               boolean hasMatched = false;
               for (Edge e : adj[x])
                  hasMatched |= e.matchedEdge;
               if (!hasMatched)
               {
                  q.add(x);
                  Z[x] = true; 
               }
            }
         }
      } 

      while (q.size() > 0)
      {
         int x = q.poll();

         if (side[x])
         {
            // Traverse unmatched edges
            for (Edge e : adj[x])
            {
               if (!Z[e.j] && !e.matchedEdge)
               {
                  q.add(e.j);
                  Z[e.j] = true;
               }
            }
         }
         else
         {
            // Traverse matched edges
            for (Edge e : adj[x])
            {
               if (!Z[e.j] && e.matchedEdge)
               {
                  q.add(e.j);
                  Z[e.j] = true;
               }
            }
         }
      }

      boolean[] inVertexCover = new boolean[N*M];
      for (int x=0; x<N*M; x++)
      {
         if (side[x])
         {
            inVertexCover[x] = !Z[x];
         }
         else
         {
            inVertexCover[x] = Z[x]; 
         }

         // But we really want the independent set
         inVertexCover[x] = !inVertexCover[x];
      }

      return inVertexCover;
   }

   public AbstractArt_ff_font(FastScanner in, PrintWriter out)
   {
      N = in.nextInt();
      M = in.nextInt();
      grid = new char[N][];
      for (int i=0; i<N; i++)
         grid[i] = in.next().toCharArray();
   
      minVertexCover = matchOppositeColors();
      System.out.println(minVertexCover);

      boolean[] independentSet1 = getIndependentSet(0);
      // out.println(Arrays.toString(independentSet1));
      boolean[] independentSet2 = getIndependentSet(1);
      // out.println(Arrays.toString(independentSet2));

      TreeSet<Character> canKeep = new TreeSet<>();
      for (int i=0; i<N; i++)
      {
         for (int j=0; j<M; j++)
         {
            if (grid[i][j] == '#')
               continue;

            int x = getNode(i,j);
            if (independentSet1[x] || independentSet2[x])
            {
               canKeep.add(grid[i][j]);
            }
         }
      }
      
      StringBuilder sb = new StringBuilder();
      for (char c : canKeep)
         sb.append(c);
      System.out.println(sb);
   }

   class Edge
   {
      int i, j;
      boolean matchedEdge;

      Edge(int i, int j, boolean matchedEdge)
      {
         this.i = i;
         this.j = j;
         this.matchedEdge = matchedEdge;
      }
   }
}


class FordFulkerson
{
   int numNodes, source, sink; 
   ArrayList<Edge>[] adj;
   boolean[] seen;

   public FordFulkerson(int numNodes)
   {
      this.source = numNodes++;
      this.sink = numNodes++;
      this.numNodes = numNodes;
      seen = new boolean[numNodes];
      adj = new ArrayList[numNodes];
      for (int i=0; i<numNodes; i++)
      {
         adj[i] = new ArrayList<>();
      }
   }

   void addEdge(int i, int j, int cap)
   {
      Edge fwd = new Edge(i, j, cap);
      Edge rev = new Edge(j, i, 0);
      fwd.rev = rev;
      rev.rev = fwd;
      adj[i].add(fwd);
      adj[j].add(rev);
   }

   int dfs(int curNode, int flowCap)
   {
      if (seen[curNode] || flowCap == 0)
         return 0;
      seen[curNode] = true;
      if (curNode == sink)
         return flowCap;

      for (Edge e : adj[curNode])
      {
         int amtSent = dfs(e.j, Math.min(e.cap, flowCap));
         if (amtSent > 0)
         {
            e.cap -= amtSent;
            e.rev.cap += amtSent;
            return amtSent;
         }
      }

      return 0;
   }

   int run()
   {
      int totalFlow = 0;
      int flowSent = -1;
      while (flowSent != 0)
      {
         Arrays.fill(seen, false);
         flowSent = dfs(source, Integer.MAX_VALUE); 
         totalFlow += flowSent;
      }
      return totalFlow;
   }

   class Edge
   {
      int i, j, cap;
      Edge rev;

      public Edge(int i, int j, int cap)
      {
         this.i = i;
         this.j = j;
         this.cap = cap;
         this.rev = null;
      }
   }
}

class FastScanner
{
   private InputStream stream;
   private byte[] buf = new byte[1024];
   private int curChar;
   private int numChars;
    
   public FastScanner(InputStream stream)
   {
      this.stream = stream;
   }
    
   int read()
   {
      if (numChars == -1)
         throw new InputMismatchException();
      if (curChar >= numChars)
      {
         curChar = 0;
         try
         {
            numChars = stream.read(buf);
         } 
         catch (IOException e) 
         {
            throw new InputMismatchException();
         }
         
         if (numChars <= 0)
            return -1;
      }
      return buf[curChar++];
   }
    
   boolean isSpaceChar(int c)
   {
      return c==' '||c=='\n'||c=='\r'||c=='\t'||c==-1;
   }
   
   boolean isEndline(int c)
   {
      return c=='\n'||c=='\r'||c==-1;
   }
   
   int nextInt()
   {
      return Integer.parseInt(next());
   }
   
   long nextLong()
   {
      return Long.parseLong(next());
   }
   
   double nextDouble()
   {
      return Double.parseDouble(next());
   }
   
   String next()
   {
      int c = read();
      while (isSpaceChar(c))
         c = read();
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isSpaceChar(c));
      return res.toString();
   }
   
   String nextLine()
   {
      int c = read();
      while (isEndline(c))
         c = read();
      
      StringBuilder res = new StringBuilder();
      do
      {
         res.appendCodePoint(c);
         c = read();
      } while(!isEndline(c));
      return res.toString();
   }
}
